==> syncope-2.1.13-source-release.zip: syncope-2.1.13/core/persistence-api/src/main/java/org/apache/syncope/core/persistence/api/entity/task/NotificationTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.api.entity.task;

import java.util.Set;
import org.apache.syncope.common.lib.types.AnyTypeKind;
import org.apache.syncope.common.lib.types.TraceLevel;
import org.apache.syncope.core.persistence.api.entity.Notification;

public interface NotificationTask extends Task {

    Notification getNotification();

    void setNotification(Notification notification);

    String getEntityKey();

    void setEntityKey(String entityKey);

    AnyTypeKind getAnyTypeKind();

    void setAnyTypeKind(AnyTypeKind anyTypeKind);

    void setSender(String sender);

    String getSender();

    Set<String> getRecipients();

    String getSubject();

    void setSubject(String subject);

    void setTextBody(String textBody);

    String getTextBody();

    void setHtmlBody(String htmlBody);

    String getHtmlBody();

    void setTraceLevel(TraceLevel traceLevel);

    TraceLevel getTraceLevel();

    boolean isExecuted();

    void setExecuted(boolean executed);

}

==> syncope-4.0.1-source-release.zip: syncope-4.0.1/core/persistence-api/src/main/java/org/apache/syncope/core/persistence/api/entity/task/NotificationTask.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.core.persistence.api.entity.task;

import java.util.Set;
import org.apache.syncope.common.lib.types.AnyTypeKind;
import org.apache.syncope.common.lib.types.TraceLevel;
import org.apache.syncope.core.persistence.api.entity.Notification;

public interface NotificationTask extends Task<NotificationTask> {

    Notification getNotification();

    void setNotification(Notification notification);

    String getEntityKey();

    void setEntityKey(String entityKey);

    AnyTypeKind getAnyTypeKind();

    void setAnyTypeKind(AnyTypeKind anyTypeKind);

    void setSender(String sender);

    String getSender();

    Set<String> getRecipients();

    String getSubject();

    void setSubject(String subject);

    void setTextBody(String textBody);

    String getTextBody();

    void setHtmlBody(String htmlBody);

    String getHtmlBody();

    void setTraceLevel(TraceLevel traceLevel);

    TraceLevel getTraceLevel();

    boolean isExecuted();

    void setExecuted(boolean executed);

}
